
# @(#)bitkeeper.sh 1.21 bryan@bigmac.bitmover.com|src/utils/bitkeeper.sh|20030620170650|47108 

init() {
	# This scripts expect to get the full path name to itself and the
	# full path name of the data file as arguments.  If there are args,
	# they come first.
	INTERACTIVE=YES
	if [ "X$1" = "X-f" ]
	then	INTERACTIVE=NO
		shift
	fi
	WISH=YES
	if [ "X$DISPLAY" = X ]
	then    WISH=NO
	else    WISH=YES
	fi
	if [ "X$1" = "X-g" ]
	then	WISH=NO
		shift
	fi
	INSTALLER=$1
	TARBALL=$2
	trap "/bin/rm -f $INSTALLER $TARBALL; exit 1" 1 2 3 15
	test $WISH = YES  && {
		mkdir /tmp/bk$$ || exit 1
		cd /tmp/bk$$ 2>/dev/null
		gunzip < $TARBALL | tar xf - bitkeeper/tk
		HERE=`pwd`
		TCL_LIBRARY=$HERE/bitkeeper/tk/lib/tcl8.3
		TK_LIBRARY=$HERE/bitkeeper/tk/lib/tk8.3
		export TCL_LIB TK_LIB
		trap "cleanup; exit 1" 1 2 3 15
	}
	DIRS="/usr/libexec /opt /usr/local"
	if [ '-n foo' = "`echo -n foo`" ]
	then	NL='\c'
		N=
	else	NL=
		N=-n
	fi
}

cleanup() {
	/bin/rm -rf /tmp/bk$$ 
	/bin/rm -f $INSTALLER $TARBALL;
}

prompt() {
	echo $N "$@ "$NL
	read choice
}

check_destination() {
	DIR=$1
	'cd' $DIR || {
		echo Can not change directories to $dir
		prompt "Press Enter to continue"
		return 1
	}
	test -d bitkeeper/. || mkdir bitkeeper
	find bitkeeper/. -type d -print | xargs chmod +w 2>/dev/null
	test -w bitkeeper/. || {
		cleanup
		echo You have no write permission on $dir/bitkeeper
		echo Perhaps you want to run this as root?
		prompt "Press Enter to continue"
		return 1
	}
	return 0
}

doit() {
	dir=/usr/libexec/bitkeeper
	for p in `echo $PATH | sed 's/:/ /g'`
	do	test -x $p/bk && {
			dir=`bk bin`
			echo ""
			echo Found BitKeeper installation in $dir ...
			echo ""
			break
		}
	done
	test -d $dir || mkdir $dir
	test -w $dir || {
		echo You do not have write permission on $dir
		cleanup
		exit 1
	}
	check_destination `echo $dir | sed s,/bitkeeper,,`
	rm -f bitkeeper/* > /dev/null 2>&1
	rm -rf bitkeeper/t bitkeeper/man > /dev/null 2>&1
    	install
	exit 0
}

links() {
	test -x /usr/bin/get && cmp -s /usr/bin/get bitkeeper/get && return

	if [ ! -w /usr/bin ]
	then
		cat <<EOF
----------------------------------------------------------------------------
You have no write permission on /usr/bin, so no links will be created there.
You need to add the bitkeeper directory to your path (not recommended), 
or symlink bk into some public bin directory.  You can do that by running

	$dir/bitkeeper/bk links $dir [destination-dir]
i.e.,
	$dir/bitkeeper/bk links $dir /usr/bin
----------------------------------------------------------------------------
EOF
	else	'cd' bitkeeper
		echo ""
		./bk links $dir/bitkeeper /usr/bin
		echo ""
		test -w /usr/bin/bk || {
			echo "We were unable to create links in /usr/bin"
			cleanup
			exit 1
		}
	fi
}

install() {
	echo Installing in `pwd`, please wait a moment...
	test -d bitkeeper/. && {
		find bitkeeper/. -print | xargs chmod +w
	}
	gunzip < $TARBALL | tar xf -
	find bitkeeper/. -print | xargs chmod a-w
	test X`bitkeeper/bk getuser` = Xroot && {
		find bitkeeper/. -print | xargs chown root
		find bitkeeper/. -print | xargs chgrp root
	}
	links

cat <<EOF

----------------------------------------------------------------------------
		    Installation was successful.

For more information, you can go to http://www.bitkeeper.com.  We strongly
urge you to go to the web site and take the "Test drive", it answers 90%
of new users' questions.

For help
	bk help
    or
	bk helptool

			      Enjoy!
----------------------------------------------------------------------------

EOF
	cleanup
	exit 0
}

init "$@"
test $INTERACTIVE = NO && doit
test $WISH = YES && {
	test -f bitkeeper/tk/bin/installer.gui || {
		echo Installation problem, no bkgui found.
		exit 1
	}
	./bitkeeper/tk/bin/bkgui -f bitkeeper/tk/bin/installer.gui $TARBALL
	STATUS=$?
	cleanup
	exit $STATUS
}
while true
do
	BAD=YES
	cat <<EOF

			==========================
			   Welcome to BitKeeper
			==========================

You are about to install BitKeeper on your system.  The installer will 
expand a gzipped tar file and place it in a directory of your choosing.  
We will create a subdirectory there called "bitkeeper" and create a few 
symlinks from "/usr/bin" into that directory.

If you want to do the install yourself, enter "none" and we will leave this
installation script and the gzipped tar archive in /tmp and you can do any
customization you might want (or just see what it is doing).

The bitkeeper directory can be anywhere, but /usr/libexec/bitkeeper is 
recommended.  For example, if you enter /usr/local when asked for the 
installation directory, we will install bitkeeper in /usr/local/bitkeeper. 

Here is a list of places you might put BitKeeper:

EOF
	for i in $DIRS
	do	echo "	$i"
	done
	echo ""
	echo $N "Installation directory: "$NL
	read dir
	if [ "X$dir" = Xnone ]
	then	cat <<EOF

----------------------------------------------------------------------------
Manual installation selected.  The files you want are:

Installation script: $INSTALLER
Gzipped tar archive: $TARBALL

If you want to make a few changes and rerun the script, you can do
so by saying:

    $INSTALLER $INSTALLER $TARBALL

Good luck.
----------------------------------------------------------------------------

EOF
		exit 0
	fi

	check_destination $dir && break
done
if [ -x bitkeeper/bk ]
then	bkver=`bitkeeper/bk version | head -1`
	cat <<EOF

----------------------------------------------------------------------------
$bkver version

	is already installed in `pwd`.
----------------------------------------------------------------------------

EOF
	prompt "Do you want to delete the existing version or exit [d/e]: "
	if [ $choice = "e" ]
	then	cleanup
		exit 1
	elif [ $choice = "d" ]
	then	rm -f bitkeeper/* > /dev/null 2>&1
		rm -rf bitkeeper/t bitkeeper/man > /dev/null 2>&1
	fi
fi
install
